Return a report of usage information for resources associated with the project identified by project_id and user identified by user_id. The value is a dictionary of resource classes paired with the sum of the allocations of that resource class for provided parameters.
Normal Response Codes: 200
Error response codes: badRequest(400)
Structs
- Request
- Request
Builder - Builder for
Request.
Enums
- Request
Builder Error - Error type for RequestBuilder