RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder<'a> { /* private fields */ }
Builder for Request.

Implementations

Source

impl<'a> RequestBuilder<'a>

pub fn consumer_type<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self

A string that consists of numbers, A-Z, and _ describing the consumer type by which to filter usage results. For example, to retrieve only usage information for ‘INSTANCE’ type consumers a parameter of consumer_type=INSTANCE should be provided. The all query parameter may be specified to group all results under one key, all. The unknown query parameter may be specified to group all results under one key, unknown.

pub fn project_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self

The uuid of a project.

pub fn user_id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The uuid of a user.

pub fn build(&self) -> Result<Request<'a>, RequestBuilderError>

Builds a new Request.

Errors

If a required field has not been initialized.

Source

impl<'a> RequestBuilder<'a>

pub fn header<K, V>(&mut self, header_name: K, header_value: V) -> &mut Self

Add a single header to the Usage.

pub fn headers<I, T>(&mut self, iter: I) -> &mut Self
where I: Iterator<Item = T>, T: Into<(Option<HeaderName>, HeaderValue)>,

Add multiple headers.