pub struct ConfigFile {
pub cache: Option<CacheConfig>,
pub clouds: Option<HashMap<String, CloudConfig>>,
pub public_clouds: Option<HashMap<String, CloudConfig>>,
}Expand description
ConfigFile structure.
Fields
cache: Option<CacheConfig>Cache configuration.
clouds: Option<HashMap<String, CloudConfig>>clouds configuration.
public_clouds: Option<HashMap<String, CloudConfig>>vendor clouds information (profiles).
Implementations
Sourceimpl ConfigFile
impl ConfigFile
Sourcepub fn builder() -> ConfigFileBuilder
pub fn builder() -> ConfigFileBuilder
A builder to create a ConfigFile by specifying which files to load.
Sourcepub fn new_with_user_specified_configs(
clouds: Option<impl AsRef<Path>>,
secure: Option<impl AsRef<Path>>,
) -> Result<Self, ConfigError>
pub fn new_with_user_specified_configs( clouds: Option<impl AsRef<Path>>, secure: Option<impl AsRef<Path>>, ) -> Result<Self, ConfigError>
Create a ConfigFile which also loads the default sources in the following order:
clouds-public.{yaml,yml,json}(seefind_vendor_filefor search paths)clouds.{yaml,yml,json}(seefind_clouds_filefor search paths)- the provided clouds file
secure.{yaml,yml,json}(seefind_secure_filefor search paths)- the provided secure file
If a source is not a valid config it will be ignored, but if one of the sources
has syntax errors (YAML/JSON) or one of the user specified configs does not
exist, a ConfigError will be returned.
Sourcepub fn new() -> Result<Self, ConfigError>
pub fn new() -> Result<Self, ConfigError>
A convenience function which calls new_with_user_specified_configs without an
additional clouds or secret file.
Sourcepub fn get_cloud_config<S: AsRef<str>>(
&self,
cloud_name: S,
) -> Result<Option<CloudConfig>, ConfigError>
pub fn get_cloud_config<S: AsRef<str>>( &self, cloud_name: S, ) -> Result<Option<CloudConfig>, ConfigError>
Get cloud connection configuration by name.
This method does not raise exception when the cloud is not found.
Sourcepub fn is_auth_cache_enabled(&self) -> bool
pub fn is_auth_cache_enabled(&self) -> bool
Return true if auth caching is enabled.
Sourcepub fn get_available_clouds(&self) -> Vec<String>
pub fn get_available_clouds(&self) -> Vec<String>
Return list of available cloud connections.