pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn consumer_type<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn consumer_type<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
A string that consists of numbers, A-Z, and _ describing the consumer type by which to filter usage results. For example, to retrieve only usage information for ‘INSTANCE’ type consumers a parameter of consumer_type=INSTANCE should be provided. The all query parameter may be specified to group all results under one key, all. The unknown query parameter may be specified to group all results under one key, unknown.
Sourcepub fn project_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn project_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The uuid of a project.